pub enum Entry<'a, K, V> {
Occupied(OccupiedEntry<'a, K, V>),
Vacant(VacantEntry<'a, K, V>),
}Expand description
A view into an entry in the map
Variants
Occupied(OccupiedEntry<'a, K, V>)
The entry corresponding to the key K exists in the map
Vacant(VacantEntry<'a, K, V>)
The entry corresponding to the key K does not exist in the map