pub struct OccupiedEntry<'a, K, V> { /* private fields */ }Expand description
An occupied entry which can be manipulated
Implementations
Sourceimpl<'a, K, V> OccupiedEntry<'a, K, V>where
K: Eq,
impl<'a, K, V> OccupiedEntry<'a, K, V>where
K: Eq,
Sourcepub fn remove_entry(self) -> (K, V)
pub fn remove_entry(self) -> (K, V)
Removes this entry from the map and yields its corresponding key and value
Sourcepub fn remove(self) -> V
pub fn remove(self) -> V
Removes this entry from the map and yields its corresponding key and value
Sourcepub fn get_mut(&mut self) -> &mut V
pub fn get_mut(&mut self) -> &mut V
Gets a mutable reference to the value associated with this entry